from sqlalchemy import Column, Integer, Text, Table
from autosubmit.database.tables import (
    metadata_obj,
    _table_change_schema,
    ExperimentTable,
    ExperimentStructureTable,
    ExperimentStatusTable,
    JobPackageTable,
    WrapperJobPackageTable,
    ExperimentRunTable,
    JobDataTable,
)

table_change_schema = _table_change_schema

## API extended SQLAlchemy Core tables

DetailsTable = Table(
    "details",
    metadata_obj,
    Column("exp_id", Integer, primary_key=True),
    Column("user", Text, nullable=False),
    Column("created", Text, nullable=False),
    Column("model", Text, nullable=False),
    Column("branch", Text, nullable=False),
    Column("hpc", Text, nullable=False),
)
"""Stores extra information. It is populated by the API."""


GraphDataTable = Table(
    "experiment_graph_draw",
    metadata_obj,
    Column("id", Integer, primary_key=True),
    Column("job_name", Text, nullable=False),
    Column("x", Integer, nullable=False),
    Column("y", Integer, nullable=False),
)
"""Stores the coordinates and it is used exclusively 
to speed up the process of generating the graph layout"""

# Module exports
__all__ = [
    "table_change_schema",
    "ExperimentTable",
    "ExperimentStructureTable",
    "ExperimentStatusTable",
    "JobPackageTable",
    "WrapperJobPackageTable",
    "ExperimentRunTable",
    "JobDataTable",
    "DetailsTable",
    "GraphDataTable",
]
