from autosubmit_api.database.adapters.experiment import ExperimentDbAdapter
from autosubmit_api.database.adapters.graph_draw import ExpGraphDrawDBAdapter
from autosubmit_api.database.adapters.join.experiment_join import (
    ExperimentJoinDbAdapter,
)


class TestExperimentDbAdapter:
    def test_operations(self, fixture_mock_basic_config):
        experiment_db = ExperimentDbAdapter()

        # Check get_all
        rows = experiment_db.get_all()
        assert len(rows) >= 4
        for expid in ["a003", "a007", "a3tb", "a6zj"]:
            assert expid in [row.get("name") for row in rows]

        # Check get_by_expid
        row = experiment_db.get_by_expid("a003")
        assert row["name"] == "a003"


class TestExpGraphDrawDBAdapter:
    def test_operations(self, fixture_mock_basic_config):
        expid = "g001"
        graph_draw_db = ExpGraphDrawDBAdapter(expid)

        # Create table
        graph_draw_db.create_table()

        # Table exists and is empty
        assert graph_draw_db.get_all() == []

        # Insert data
        data = [
            {"id": 1, "job_name": "job1", "x": 1, "y": 2},
            {"id": 2, "job_name": "job2", "x": 2, "y": 3},
        ]
        assert graph_draw_db.insert_many(data) == len(data)

        # Get data
        assert graph_draw_db.get_all() == data

        # Delete data
        assert graph_draw_db.delete_all() == len(data)

        # Table is empty
        assert graph_draw_db.get_all() == []


class TestExperimentJoinDbAdapter:
    def test_search(self, fixture_mock_basic_config):
        experiment_join_db = ExperimentJoinDbAdapter()

        # Check search
        rows, total = experiment_join_db.search(limit=3)
        assert len(rows) == 3
        assert total >= 4

        for row in rows:
            assert row.get("status")
